@@ -6,10 +6,10 @@ use base 'Graph::Fast';
 
 sub noop { 1; }
 
-*add_weighted_edge = \&Graph::Fast::addedge;
+*add_weighted_edge = \&Graph::Fast::add_edge;
 
 sub add_edge {
-	$_[0]->addedge($_[1], $_[2], 1);
+	Graph::Fast::add_edge($_[0], $_[1], $_[2], 1);
 }
 
 *SP_Dijkstra = \&Graph::Fast::dijkstra;
